bayespy.inference.vmp.nodes.beta.BetaMoments
============================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. autoclass:: BetaMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~BetaMoments.add_converter
      ~BetaMoments.compute_dims_from_values
      ~BetaMoments.compute_fixed_moments
      ~BetaMoments.get_converter
   
   

   
   
   